------------------------------------------------------------------------------
-- SellableItemDrops - Logging your sellable item drops
------------------------------------------------------------------------------
-- Modules/GUI_debug.lua - Debug Tab
--
-- Author: Expelliarm5s / January 2020 / All Rights Reserved
--
-- Version 0.4.17
------------------------------------------------------------------------------
-- luacheck: ignore 212

local addonName, addon = ...
local GUI = addon:GetModule("GUI")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
local AceGUI = LibStub("AceGUI-3.0")
local private = {}
------------------------------------------------------------------------------

function GUI.EnableDebugLog()
	if not private.isDebugLog then
		GUI.guiTabs.order[#GUI.guiTabs.order + 1] = "debug"
		addon.isDebugLog = true
		private.isDebugLog = true
		GUI:Printf(L["DebugLog enabled"])
	end
	if addon.DebugLog then
		addon.DebugLog(L["DebugLog enabled"])
	end
end

GUI.guiTabs.texts["debug"] = {
	title=L["Debugging"], desc=L["Debugging"]}

-- GUI.guiTabs.order[#GUI.guiTabs.order + 1] = "debug"

GUI.guiTabsSelect["debug"] = function(container, group)
	GUI:DebugPrintf("Select Tab %s: %s", group, tostring(container))
	if not container then
		GUI:DebugPrintf("Select Tab: container is nil")
	end

	-- min. Size
	GUI.display.frame:SetMinResize(500, 600)

	local grp1 = AceGUI:Create("SIDInlineGroup")
	grp1:SetLayout("Fill")
	grp1:SetFullWidth(true)
	grp1:SetFullHeight(true)
	if grp1.SetTitle then
		local wowV, wowP = GetBuildInfo()
		local wowVersion = "WoW, " .. (addon.isClassic and "classic" or "retail") .. ", Version " .. wowV .. ", Build " .. wowP
		grp1:SetTitle(addon.METADATA.NAME .. " " .. addon.METADATA.VERSION .. " - " .. wowVersion)
	end

	local titles = {
		{text=L["Time"], relWidth=0.2},
		{text=L["Message"], relWidth=0.8},
	}

	local eventHandlers = {
		OnEnter = GUI.DataFrame_OnEnter,
		OnLeave = GUI.DataFrame_OnLeave,
		OnClick = function(_, data, _)
			if not data then return end
			end,
		}

	container.titleStatusText = {
		L[""],
		L[""],
		}
	container.statusText = L[""]

	GUI.dataDebugLog = AceGUI:Create("SIDData")
	GUI.dataDebugLog:DoRedraw(false)
	-- GUI.dataDebugLog:SetTextSize(11)
	GUI.dataDebugLog:SetEventHandlers(eventHandlers)
	GUI.dataDebugLog:SetTitles(titles)
	GUI.dataDebugLog:SetSortTitle(1)
	grp1:AddChild(GUI.dataDebugLog)

	container:AddChild(grp1)

	GUI.dataDebugLog:SetContent(private.GetDebugLogData() or {})
	GUI.dataDebugLog:DoRedraw(true)

	return container
end

function GUI:UpdateDebugLogData(updated)
	GUI:DebugPrintf("UpdateDebugLogData(" .. tostring(updated) .. ")")
	if GUI.view == "debug" and GUI.display then
		if (updated) then
			GUI.dataDebugLog:SetContent(private.GetDebugLogData())
			GUI.container:Reload()
		end
	end
end

function private.GetDebugLogData()
	GUI:DebugPrintf("GetDebugLogData()")
	if GUI.view ~= "debug" or not GUI.display then
		GUI:DebugPrintf("... nothing done.")
		return
	end

	addon.debuglog = addon.debuglog or {}
	local content = {}
	for _, data in pairs(addon.debuglog) do
		local en = {}
		en.data = {}
		en.data[1] = {GUI:TimeToString(data.time), data.time}
		en.data[2] = {data.message, data.message}
		tinsert(content, en)
	end
	return content
end

-- EOF

